# URL-obfuscator

A simple Python Program to obfuscate URLs to make phishing URLS more difficult to detect.

Quick Installation
------------------

To Install from [PyPI](https://pypi.org/project/badurls/):

Run the following commands in Linux terminal / Windows powershell / command prompt to install from pypi:-

```
pip install badurls
```
Then type these commands to get started:-

```
badurls
```

This tool uses public open redirects and http basic auth to make phishing attacks
difficult to detect. Includes Tor onion services which are vulnerable to open redirects too.

This Tool was originally developed to check effectiveness of Antiviruses and user education as defensive measures against obfuscated URLs.

THE DEVELOPER WILL NOT BE RESPONSIBLE FOR ANY DAMAGES ARISING FROM THE USE OF THIS TOOL. THE USERS WILL BE FULLY RESPONSIBLE FOR THE CONTENT THEY USE USING THIS TOOL.
THIS TOOL WAS DEVELOPED FOR EDUCATIONAL AND ETHICAL EXPERIMENTING PURPOSE ONLY AND NOT FOR SPAMMING OR TARGETING ANYONE.
